@@ -14,6 +14,27 @@ const (
 	nullBody                 = "null"
 )
 
+type UpdateWebhookRequest struct {
+	URL     string            `json:"url,omitempty"`
+	Headers map[string]string `json:"headers,omitempty"`
+}
+
+type Webhook struct {
+	UUID       string            `json:"uuid"`
+	IsEditable bool              `json:"isEditable"`
+	URL        string            `json:"url"`
+	Headers    map[string]string `json:"headers"`
+}
+
+type WebhookResults struct {
+	Result []*Webhook `json:"results"`
+}
+
+type AddWebhookRequest struct {
+	URL     string            `json:"url"`
+	Headers map[string]string `json:"headers,omitempty"`
+}
+
 type IndexConfig struct {
 	// Uid is the unique identifier of a given index.
 	Uid string
@@ -79,6 +100,7 @@ type Settings struct {
 	Embedders            map[string]Embedder    `json:"embedders,omitempty"`
 	PrefixSearch         *string                `json:"prefixSearch,omitempty"`
 	FacetSearch          bool                   `json:"facetSearch,omitempty"`
+	Chat                 *Chat                  `json:"chat,omitempty"`
 }
 
 type LocalizedAttributes struct {
@@ -113,6 +135,23 @@ type Faceting struct {
 	SortFacetValuesBy map[string]SortFacetType `json:"sortFacetValuesBy"`
 }
 
+type Chat struct {
+	Description              string            `json:"description,omitempty"`
+	DocumentTemplate         string            `json:"documentTemplate,omitempty"`
+	DocumentTemplateMaxBytes int               `json:"documentTemplateMaxBytes,omitempty"`
+	SearchParameters         *SearchParameters `json:"searchParameters,omitempty"`
+}
+
+type SearchParameters struct {
+	Limit                 int64                `json:"limit,omitempty"`
+	AttributesToSearchOn  []string             `json:"attributesToSearchOn,omitempty"`
+	MatchingStrategy      MatchingStrategy     `json:"matchingStrategy,omitempty"`
+	Sort                  []string             `json:"sort,omitempty"`
+	Distinct              string               `json:"distinct,omitempty"`
+	Hybrid                *SearchRequestHybrid `json:"hybrid,omitempty"`
+	RankingScoreThreshold float64              `json:"rankingScoreThreshold,omitempty"`
+}
+
 // Embedder represents a unified configuration for various embedder types.
 //
 // Specs: https://www.meilisearch.com/docs/reference/api/settings#body-21
@@ -152,6 +191,12 @@ type Embedder struct {
 	Pooling                  EmbedderPooling        `json:"pooling,omitempty"`
 	IndexingEmbedder         *Embedder              `json:"indexingEmbedder,omitempty"` // For Composite
 	SearchEmbedder           *Embedder              `json:"searchEmbedder,omitempty"`   // For Composite
+	IndexingFragments        map[string]Fragment    `json:"indexingFragments,omitempty"`
+	SearchFragments          map[string]Fragment    `json:"searchFragments,omitempty"`
+}
+
+type Fragment struct {
+	Value map[string]any `json:"value,omitempty"`
 }
 
 // Distribution represents a statistical distribution with mean and standard deviation (sigma).
@@ -398,6 +443,7 @@ type SearchRequest struct {
 	RankingScoreThreshold   float64                  `json:"rankingScoreThreshold,omitempty"`
 	FederationOptions       *SearchFederationOptions `json:"federationOptions,omitempty"`
 	Locales                 []string                 `json:"locales,omitempty"`
+	Media                   map[string]any           `json:"media,omitempty"`
 }
 
 type SearchFederationOptions struct {
@@ -485,6 +531,7 @@ type DocumentsQuery struct {
 	Filter          interface{} `json:"filter,omitempty"`
 	RetrieveVectors bool        `json:"retrieveVectors,omitempty"`
 	Ids             []string    `json:"ids,omitempty"`
+	Sort            []string    `json:"sort,omitempty"`
 }
 
 // SimilarDocumentQuery is query parameters of similar documents
@@ -536,6 +583,8 @@ type ExperimentalFeaturesBase struct {
 	ContainsFilter          *bool `json:"containsFilter,omitempty"`
 	Network                 *bool `json:"network,omitempty"`
 	CompositeEmbedders      *bool `json:"compositeEmbedders,omitempty"`
+	ChatCompletions         *bool `json:"chatCompletions,omitempty"`
+	MultiModal              *bool `json:"multimodal,omitempty"`
 }
 
 type ExperimentalFeaturesResult struct {
@@ -545,6 +594,8 @@ type ExperimentalFeaturesResult struct {
 	ContainsFilter          bool `json:"containsFilter"`
 	Network                 bool `json:"network"`
 	CompositeEmbedders      bool `json:"compositeEmbedders"`
+	ChatCompletions         bool `json:"chatCompletions"`
+	MultiModal              bool `json:"multimodal,omitempty"`
 }
 
 type SwapIndexesParams struct {
@@ -649,3 +700,97 @@ type BatchesQuery struct {
 	AfterStartedAt   time.Time
 	AfterFinishedAt  time.Time
 }
+
+type ExportParams struct {
+	URL         string                        `json:"url,omitempty"`
+	APIKey      string                        `json:"apiKey,omitempty"`
+	PayloadSize string                        `json:"payloadSize,omitempty"`
+	Indexes     map[string]IndexExportOptions `json:"indexes,omitempty"`
+}
+
+type IndexExportOptions struct {
+	Filter           string `json:"filter,omitempty"`
+	OverrideSettings bool   `json:"overrideSettings,omitempty"`
+}
+
+type ChatWorkspace struct {
+	UID string `json:"uid"`
+}
+
+type ChatWorkspaceSettings struct {
+	Source       ChatSource                    `json:"source"`
+	OrgId        string                        `json:"orgId"`
+	ProjectId    string                        `json:"projectId"`
+	ApiVersion   string                        `json:"apiVersion"`
+	DeploymentId string                        `json:"deploymentId"`
+	BaseUrl      string                        `json:"baseUrl"`
+	ApiKey       string                        `json:"apiKey,omitempty"`
+	Prompts      *ChatWorkspaceSettingsPrompts `json:"prompts"`
+}
+
+type ChatWorkspaceSettingsPrompts struct {
+	System              string `json:"system"`
+	SearchDescription   string `json:"searchDescription"`
+	SearchQParam        string `json:"searchQParam"`
+	SearchFilterParam   string `json:"searchFilterParam"`
+	SearchIndexUidParam string `json:"searchIndexUidParam"`
+}
+
+type ListChatWorkspace struct {
+	Results []*ChatWorkspace `json:"results"`
+	Offset  int64            `json:"offset"`
+	Limit   int64            `json:"limit"`
+	Total   int64            `json:"total"`
+}
+
+type ListChatWorkSpaceQuery struct {
+	Limit  int64
+	Offset int64
+}
+
+type ChatCompletionQuery struct {
+	Model    string                   `json:"model"`
+	Messages []*ChatCompletionMessage `json:"messages"`
+	Stream   bool                     `json:"stream"`
+}
+
+type ChatCompletionMessage struct {
+	Role    ChatRole `json:"role"`
+	Content string   `json:"content"`
+}
+
+type ChatCompletionStreamChunk struct {
+	ID                string                  `json:"id"`
+	Object            *string                 `json:"object,omitempty"`
+	Created           Timestampz              `json:"created,omitempty"`
+	Model             string                  `json:"model,omitempty"`
+	Choices           []*ChatCompletionChoice `json:"choices"`
+	ServiceTier       *string                 `json:"service_tier,omitempty"`
+	SystemFingerprint *string                 `json:"system_fingerprint,omitempty"`
+	Usage             any                     `json:"usage,omitempty"`
+}
+
+type ChatCompletionChoice struct {
+	Index        int64                      `json:"index"`
+	Delta        *ChatCompletionChoiceDelta `json:"delta"`
+	FinishReason *string                    `json:"finish_reason,omitempty"`
+	Logprobs     any                        `json:"logprobs"`
+}
+
+type ChatCompletionChoiceDelta struct {
+	Content      *string   `json:"content,omitempty"`
+	Role         *ChatRole `json:"role,omitempty"`
+	Refusal      *string   `json:"refusal,omitempty"`
+	FunctionCall *string   `json:"function_call,omitempty"`
+	ToolCalls    *string   `json:"tool_calls,omitempty"`
+}
+
+type Timestampz int64
+
+func (t Timestampz) String() string {
+	return time.Unix(int64(t), 0).UTC().Format(time.RFC3339)
+}
+
+func (t Timestampz) ToTime() time.Time {
+	return time.Unix(int64(t), 0).UTC()
+}
